#
# spec file for package perl-HTTP-Tiny
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name HTTP-Tiny
Name:           perl-HTTP-Tiny
Version:        0.88.0
Release:        2.2
%define cpan_version 0.088
Provides:       perl(HTTP::Tiny) = 0.88.0
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Small, simple, correct HTTP/1.1 client
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DA/DAGOLDEN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IPC::Cmd)
BuildRequires:  perl(Test::More) >= 0.96
%undefine       __perllib_provides
Recommends:     perl(HTTP::CookieJar) >= 0.001
Recommends:     perl(IO::Socket::IP) >= 0.32
Recommends:     perl(IO::Socket::SSL) >= 1.42
Recommends:     perl(Mozilla::CA) >= 20160104
Recommends:     perl(Net::SSLeay) >= 1.49
%{perl_requires}

%description
This is a very simple HTTP/1.1 client, designed for doing simple requests
without the overhead of a large framework like LWP::UserAgent.

It is more correct and more complete than HTTP::Lite. It supports proxies
and redirection. It also correctly resumes after EINTR.

If IO::Socket::IP 0.25 or later is installed, HTTP::Tiny will use it
instead of IO::Socket::INET for transparent support for both IPv4 and IPv6.

Cookie support requires HTTP::CookieJar or an equivalent class.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.mkdn README
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Jul 12 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.088
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.088     2023-07-11 08:52:54-04:00 America/New_York
    [DOCS]
  - Update metadata to point to new Perl-Toolchain-Gang repository.
* Mon Jul  3 2023 Lars Vogdt <lars@linux-schulserver.de>
- updated to 0.086
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.086     2023-06-22 10:06:37-04:00 America/New_York
    [FIXED]
  - Fix code to use `$ENV{PERL_HTTP_TINY_SSL_INSECURE_BY_DEFAULT}` as documented.
  0.084     2023-06-14 06:35:01-04:00 America/New_York
  - No changes from 0.083-TRIAL.
  0.083     2023-06-11 07:05:45-04:00 America/New_York (TRIAL RELEASE)
    [!!! SECURITY !!!]
  - Changes the `verify_SSL` default parameter from `0` to `1`.
    Fixes CVE-2023-31486 (bsc#1211002)
  - `$ENV{PERL_HTTP_TINY_SSL_INSECURE_BY_DEFAULT}` can be used to restore the
    old default if required.
* Tue Jul 26 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.082
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.082     2022-07-25 09:45:34-04:00 America/New_York
  - No changes from 0.081-TRIAL.
  0.081     2022-07-17 09:01:51-04:00 America/New_York (TRIAL RELEASE)
    [FIXED]
  - No longer deletes the 'headers' key from post_form arguments hashref.
    [DOCS]
  - Noted that request/response content are handled as raw bytes.
* Sat Nov  6 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.080
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.080     2021-11-05 08:15:46-04:00 America/New_York
  - No changes from 0.079-TRIAL.
  0.079     2021-11-04 12:33:43-04:00 America/New_York (TRIAL RELEASE)
    [FIXED]
  - Fixed uninitialized value warnings on older Perls when the REQUEST_METHOD
    environment variable is set and CGI_HTTP_PROXY is not.
* Tue Aug  3 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.078
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.078     2021-08-02 09:24:03-04:00 America/New_York
  - No changes from 0.077-TRIAL.
  0.077     2021-07-22 13:07:14-04:00 America/New_York (TRIAL RELEASE)
    [ADDED]
  - Added a `patch` helper method for the HTTP `PATCH` verb.
  - If the REQUEST_METHOD environment variable is set, then CGI_HTTP_PROXY
    replaces HTTP_PROXY.
    [FIXED]
  - Unsupported scheme errors early without giving an uninitialized value
    warning first.
  - Sends Content-Length: 0 on empty body PUT/POST.  This is not in the spec,
    but some servers require this.
  - Allows optional status line reason, as clarified in RFC 7230.
  - Ignore SIGPIPE on reads as well as writes, as IO::Socket::SSL says that
    SSL reads can also send writes as a side effect.
  - Check if a server has closed a connection before preserving it for reuse.
    [DOCS]
  - Clarified that exceptions/errors result in 599 status codes.
    [PREREQS]
  - Optional IO::Socket::IP prereq must be at least version 0.32 to be used.
    This ensures correct timeout support.
* Sat Aug 25 2018 coolo@suse.com
- updated to 0.076
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.076     2018-08-05 21:07:38-04:00 America/New_York
  - No changes from 0.075-TRIAL.
  0.075     2018-08-01 07:03:36-04:00 America/New_York (TRIAL RELEASE)
    [CHANGED]
  - The 'peer' option now also can take a code reference
* Tue Jul 31 2018 coolo@suse.com
- updated to 0.074
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.074     2018-07-30 15:35:44-04:00 America/New_York
  - No changes from 0.073-TRIAL.
  0.073     2018-07-24 11:33:53-04:00 America/New_York (TRIAL RELEASE)
    0.071 never made it to CPAN; skipping to 0.073
    [DOCS]
  - Documented 'protocol' field in response hash.
  0.071     2018-04-22 14:45:43+02:00 Europe/Oslo (TRIAL RELEASE)
    [DOCS]
  - Documented that method argument to request() is case-sensitive.
    [INTERNAL]
  - Minor regex cleanup
  - Updated .travis.yml for recent Perls
* Tue Oct 11 2016 coolo@suse.com
- updated to 0.070
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.070     2016-10-09 23:23:28-04:00 America/New_York
  - No changes from 0.069-TRIAL.
  0.069     2016-10-05 11:35:58-04:00 America/New_York (TRIAL RELEASE)
    [INTERNAL]
  - Lazy load Carp only if needed.
* Wed Sep 28 2016 coolo@suse.com
- updated to 0.068
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
* Tue Sep 27 2016 coolo@suse.com
- updated to 0.068
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
* Mon Sep 26 2016 coolo@suse.com
- updated to 0.068
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
* Sun Sep 25 2016 coolo@suse.com
- updated to 0.068
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
* Sat Sep 24 2016 coolo@suse.com
- updated to 0.068
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.068     2016-09-23 16:10:03-04:00 America/New_York
  - No changes from 0.067-TRIAL.
  0.067     2016-09-14 11:43:14-04:00 America/New_York (TRIAL RELEASE)
    [FIXED]
  - Includes redirect history when issuing a 599 internal error.
  0.065     2016-09-09 22:42:43-04:00 America/New_York (TRIAL RELEASE)
    [TESTS]
  - Try harder to clean up environment in t/140_proxy.t (needed for VMS)
* Thu Aug 18 2016 coolo@suse.com
- updated to 0.064
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.064     2016-08-16 21:37:51-04:00 America/New_York
  - No changes from 0.063-TRIAL
  0.063     2016-08-08 12:18:03-04:00 America/New_York (TRIAL RELEASE)
    [FIXED]
  - Fixed chunked transfer encoding, which previously omitted a trailing
    CRLF.
  0.061     2016-08-05 12:10:19-04:00 America/New_York (TRIAL RELEASE)
    [FIXED]
  - Avoid overwriting 'If-Modified-Since' header in mirror() if
    the header already exists in something other than lower-case.
    [TESTS]
  - Normalize CRLF when reading test data files in t\150-post_form.t
    on Win32
  0.059     2016-07-29 16:10:32-04:00 America/New_York (TRIAL RELEASE)
    [FIXED]
  - Timeout can now be set as a constructor argument again.
  - CVE-2016-1238: avoid loading optional modules from
    @INC path with `.` at the end.
    [TESTS]
  - Updated tests for a future perl which may omit `.` from
    the list of directories in @INC by default.
* Thu May  5 2016 coolo@suse.com
- updated to 0.058
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.058     2016-05-03 11:29:57-04:00 America/New_York
  - No changes from 0.057
  0.057     2016-04-18 10:17:00-04:00 America/New_York (TRIAL RELEASE)
    [ADDED]
  - Added support for the SSL_CERT_FILE environment variable.
  - Added 'peer' attribute to force a connection to a particular
    server.
  - Added 'connected' method to allow introspection of persistent
    connections.
  - An array reference of redirection result hash references is included
    in the final response hash reference (but only if redirects occur).
    [CHANGED]
  - Because folded headers are obsoleted in the revised RFCs, if CRLF is
    found in header values followed by one or more spaces, they are all
    replaced by a single space.
    [FIXED]
  - Per the RFC, control headers are now sent first before other headers
    (which are sent in arbitrary order).
  - Only well-known headers have their case canonicalized; all other
    headers are sent in the case provided by the user.
  - The 'keep_alive' option now also sets the SO_KEEPALIVE option
    on the underlying socket to help with long-lived, idle connections.
  - Request header field values are now validated against the RFC rules
    (i.e. empty or else space-or-tab separated tokens of printable
    characters).
* Wed May 20 2015 coolo@suse.com
- updated to 0.056
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.056     2015-05-19 06:00:40-04:00 America/New_York
  - No changes from 0.055
  0.055     2015-05-07 18:13:41-04:00 America/New_York (TRIAL RELEASE)
    [ADDED]
  - Added 'can_ssl' method to detect SSL support before trying and
    failing with a fatal exception.
  - Added support for 308 redirects
    [FIXED]
  - When specifying a custom CA file, if that file is missing or
    unreadable, HTTP::Tiny will no longer fall back to a default CA
    [DOCUMENTED]
  - Noted units are bytes for max_size
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.054
  see /usr/share/doc/packages/perl-HTTP-Tiny/Changes
  0.054     2015-01-27 07:18:19-05:00 America/New_York
    [ADDED]
  - Added more fallback paths to find CA files (thanks golang)
    [DOCUMENTED]
  - Fixed a typo
  0.053     2014-12-11 23:42:17-05:00 America/New_York
    [FIXED]
  - Defended tests against HTTP_PROXY set in the environment
  0.052     2014-12-11 15:23:54-05:00 America/New_York
    [CHANGED]
  - Proxy allowed from environment variable HTTP_PROXY (uppercase) unless
    REQUEST_METHOD is also set.
  0.051     2014-11-17 22:58:44-05:00 America/New_York
    [FIXED]
  - Checks for threads without loading threads.pm
  0.050     2014-09-23 15:30:18-04:00 America/New_York
    [FIXED]
  - Fixed CONNECT requests for some proxies
* Mon Sep 15 2014 coolo@suse.com
- updated to 0.049
    [FIXED]
  - 'keep_alive' is now fork-safe and thread-safe
  0.048     2014-08-21 13:19:51-04:00 America/New_York
    [FIXED]
  - Protected proxy tests from ALL_PROXY in the environment
  0.047     2014-07-29 14:09:05-04:00 America/New_York
    [CHANGED]
  - Updated Mozilla::CA module recommendation version to 20130114
    [FIXED]
  - Fixed t/00-report-prereqs.t when CPAN::Meta is not installed
  0.046     2014-07-21 10:32:32-04:00 America/New_York
    [FIXED]
  - Empty header fields are now allowed; headers with the 'undef' value
    will be rendered as an empty header.
    [DOCUMENTED]
  - Updated HTTP/1.1 spec description from RFC 2616 to RFC 7230-7235
  0.045     2014-07-19 23:17:28-04:00 America/New_York (TRIAL RELEASE)
    [FIXED]
  - Fixed t/002_croakage.t for various operating systems.
  0.044     2014-07-16 23:46:09-04:00 America/New_York
    [CHANGED]
  - Providing a custom 'Host' header is now a fatal exception.  Previously, it
    was silently ignored, as the RFC mandates that Host be set from the
    URL, but ignoring it could lead to unexpected, confusing errors.
  - optimized URL splitting
  - Passing 'undef' for any proxy attribute will prevent HTTP::Tiny from
    setting the proxy from the environment.
* Fri Mar  7 2014 coolo@suse.com
- updated to 0.043
    [FIXED]
  - Does not send absolute request URI when tunneling SSL via proxy
  - Fixes regression in setting host name to verify SSL
  - Protects tests from https_proxy and all_proxy when doing mock testing
  0.042     2014-02-18 11:23:17EST-0500 America/New_York
    [ADDED]
  - If IO::Socket::IP 0.25+ is installed, HTTP::Tiny will use it for
    transparent IPv4 or IPv6 support.
  0.041     2014-02-17 13:07:54-05:00 America/New_York
    [no code change, only an amended Changes file]
    [INCOMPATIBLE CHANGES (from 0.039)]
  - The 'proxy' attribute no longer takes precedence over the
    'http_proxy' environment variable.  With the addition of http_proxy
    and https_proxy attributes (and corresponding environment variable
    defaults), the legacy 'proxy' attribute now maps to the
    all_proxy/ALL_PROXY environment variable and only takes effect when
    other proxy attributes are not defined.
    [ADDED (since 0.039)]
  - Added 'keep_alive' attribute for single-server persistent connections
    (Clinton Gormley)
  - Added support for Basic authorization with proxies
  - Added support for https proxies via CONNECT
    [FIXED (since 0.039)]
  - Requests are made with one less write for lower latency (Martin
    Evans)
  0.040     2014-02-17 13:02:47-05:00 America/New_York
    [INCOMPATIBLE CHANGES]
  - The 'proxy' attribute no longer takes precedence over the
    'http_proxy' environment variable.  With the addition of http_proxy
    and https_proxy attributes (and corresponding environment variable
    defaults), the legacy 'proxy' attribute now maps to the
    all_proxy/ALL_PROXY environment variable and only takes effect when
    other proxy attributes are not defined.
    [ADDED]
  - Added support for Basic authorization with proxies
  - Added support for https proxies via CONNECT
* Fri Nov 29 2013 coolo@suse.com
- updated to 0.039
    [FIXED]
  - Temporary file creating during mirror() is now opened with O_EXCL
    for added security
* Mon Nov 25 2013 coolo@suse.com
- updated to 0.038
  [FIXED]
  - Fixed a bug where authentication parameters in the URL would override
    an existing Authorization header
  - Basic authentication in the URL is now unescaped before being encoded
    into the authentication header
  [DOCUMENTED]
  - Added HTTP::Tiny::UA to SEE ALSO and suggested it as the appropriate
    place for new features
* Sat Oct  5 2013 coolo@suse.com
- rewrite spec file to avoid man page conflict
* Thu Sep 26 2013 darin@darins.net
- update to 0.036
  * Compile test could hang on Windows
  * Dropped configure_requires for ExtUtils::MakeMaker to 6.17
  * Updated support files
  See a complete changelog:
  http://cpansearch.perl.org/src/DAGOLDEN/HTTP-Tiny-0.036/Changes
* Fri Apr  1 2011 pascal.bleser@opensuse.org
- update to 0.012:
  * mirror() now uses binmode during output (RT #67118)
  * noted that SSL certificates are not verified against CA's (RT #66907)
* Thu Mar 17 2011 pascal.bleser@opensuse.org
- initial version (0.010)
